Crate rusty_bubbles

Crate rusty_bubbles 

Cleanroom Rust port of upstream Go source file: bubbles.go Upstream Target Tag / Version: v2.1.0

# Bubbles

Components for Bubble Tea applications. These components are used in production in Glow, Charm and many other applications.

Ported packages:

Modules

cursor
Cleanroom Rust port of upstream Go source file: cursor/cursor.go Upstream Target Tag / Version: v2.1.0
filepicker
Cleanroom Rust port of upstream Go source file: filepicker/filepicker.go Cleanroom Rust port of upstream Go source file: filepicker/hidden_unix.go Upstream Target Tag / Version: v2.1.0
help
Cleanroom Rust port of upstream Go source file: help/help.go Upstream Target Tag / Version: v2.1.0
internal
Cleanroom Rust port of upstream Go source file: internal/internal.go (package layout) Upstream Target Tag / Version: v2.1.0
key
Cleanroom Rust port of upstream Go source file: key/key.go Upstream Target Tag / Version: v2.1.0
list
Cleanroom Rust port of upstream Go source file: list/list.go Cleanroom Rust port of upstream Go source file: list/defaultitem.go Cleanroom Rust port of upstream Go source file: list/keys.go Cleanroom Rust port of upstream Go source file: list/style.go Upstream Target Tag / Version: v2.1.0
paginator
Cleanroom Rust port of upstream Go source file: paginator/paginator.go Upstream Target Tag / Version: v2.1.0
progress
Cleanroom Rust port of upstream Go source file: progress/progress.go Upstream Target Tag / Version: v2.1.0
spinner
Cleanroom Rust port of upstream Go source file: spinner/spinner.go Upstream Target Tag / Version: v2.1.0
stopwatch
Cleanroom Rust port of upstream Go source file: stopwatch/stopwatch.go Upstream Target Tag / Version: v2.1.0
table
Cleanroom Rust port of upstream Go source file: table/table.go Upstream Target Tag / Version: v2.1.0
textarea
Cleanroom Rust port of upstream Go source file: textarea/textarea.go Upstream Target Tag / Version: v2.1.0
textinput
Cleanroom Rust port of upstream Go source file: textinput/textinput.go Cleanroom Rust port of upstream Go source file: textinput/styles.go Upstream Target Tag / Version: v2.1.0
timer
Cleanroom Rust port of upstream Go source file: timer/timer.go Upstream Target Tag / Version: v2.1.0
viewport
Cleanroom Rust port of upstream Go source file: viewport/viewport.go Cleanroom Rust port of upstream Go source file: viewport/keymap.go Cleanroom Rust port of upstream Go source file: viewport/highlight.go Upstream Target Tag / Version: v2.1.0