Module cursor

Module cursor 

Cleanroom Rust port of upstream Go source file: cursor/cursor.go Upstream Target Tag / Version: v2.1.0

# Cursor

A virtual cursor to support the textinput and textarea elements.

Structs

BlinkMsg
BlinkMsg signals that the cursor should blink. It contains metadata that allows us to tell if the blink message is the one we’re expecting.
Model
Model is the Bubble Tea model for this cursor element.

Enums

Mode
Mode describes the behavior of the cursor.

Functions

blink
Blink is a command used to initialize cursor blinking.
new
New creates a new model with default settings.