pub struct Model {
pub style: Style,
pub text_style: Style,
pub blink_speed: Duration,
pub is_blinked: bool,
/* private fields */
}Expand description
Model is the Bubble Tea model for this cursor element.
Fields
style: StyleStyle styles the cursor block.
text_style: StyleTextStyle is the style used for the cursor when it is blinking (hidden), i.e. displaying normal text.
blink_speed: DurationBlinkSpeed is the speed at which the cursor blinks. This has no effect
unless Mode::Blink is set.
is_blinked: boolIsBlinked is the state of the cursor blink. When true, the cursor is hidden.
Implementations