Module filepicker

Module filepicker 

Cleanroom Rust port of upstream Go source file: filepicker/filepicker.go Cleanroom Rust port of upstream Go source file: filepicker/hidden_unix.go Upstream Target Tag / Version: v2.1.0

# FilePicker

A file picker component for Bubble Tea applications.

The humanized byte formatting is an inline port of github.com/dustin/go-humanize’s Bytes function, and the permission string is a port of Go’s os.FileMode::String.

Structs

DirEntry
DirEntry mirrors a single entry in a directory listing.
ErrorMsg
errorMsg is sent when reading a directory fails.
KeyMap
KeyMap defines key bindings for each user action.
Model
Model represents a file picker.
ReadDirMsg
readDirMsg is sent after a directory has been read.
Stack
Stack is a simple LIFO stack of indices used to remember navigation history.
Styles
Styles defines the possible customizations for styles in the file picker.

Functions

default_key_map
DefaultKeyMap defines the default keybindings.
default_styles
DefaultStyles defines the default styling for the file picker.
new
New returns a new filepicker model with default styling and key bindings.