Module help

Module help 

Cleanroom Rust port of upstream Go source file: help/help.go Upstream Target Tag / Version: v2.1.0

# Help

A simple help view for Bubble Tea applications.

Structs

Model
Model contains the state of the help view.
Styles
Styles is a set of available style definitions for the Help bubble.

Traits

KeyMap
KeyMap is a map of keybindings used to generate help. Since it’s an interface it can be any type, though a struct or a map of bindings are likely candidates.

Functions

default_dark_styles
DefaultDarkStyles returns a set of default styles for dark backgrounds.
default_light_styles
DefaultLightStyles returns a set of default styles for light backgrounds.
default_styles
DefaultStyles returns a set of default styles for the help bubble. Light or dark styles can be selected by passing is_dark.
new
New creates a new help view with some useful defaults.