Module fuzzy

Module fuzzy 

Fuzzy string matching, ported inline from github.com/sahilm/fuzzy (used by the list component’s DefaultFilter).

Provides fuzzy string matching optimized for filenames and code symbols in the style of Sublime Text, VSCode, IntelliJ IDEA et al.

Structs

Match
Match represents a matched string.

Functions

find
Find looks up pattern in data and returns matches in descending order of match quality. Match quality is determined by a set of bonus and penalty rules.
find_no_sort
FindNoSort is an alternative Find implementation that does not sort the results in the end.
score_cmp
SortOrder is used by callers that sort matches themselves (matching Go’s sort.Stable on score descending).