Hasher

Trait Hasher 

pub trait Hasher {
    // Required method
    fn hash(&self) -> String;
}
Hasher is an interface that requires a Hash method. The Hash method is expected to return a string representation of the hash of the object.

Required Methods

fn hash(&self) -> String

Hash returns the string representation of the hash of the object.

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors