pub fn new_binding(opts: Vec<BindingOpt>) -> BindingExpand description
NewBinding returns a new keybinding from a set of BindingOpt options.
pub fn new_binding(opts: Vec<BindingOpt>) -> BindingNewBinding returns a new keybinding from a set of BindingOpt options.