Binding

Struct Binding 

pub struct Binding { /* private fields */ }
Binding describes a set of keybindings and, optionally, their associated help text.

Implementations

Source

impl Binding

pub fn set_keys(&mut self, keys: &[&str])

SetKeys sets the keys for the keybinding.

pub fn keys(&self) -> Vec<String>

Keys returns the keys for the keybinding.

pub fn set_help(&mut self, key: &str, desc: &str)

SetHelp sets the help text for the keybinding.

pub fn help(&self) -> Help

Help returns the Help information for the keybinding.

pub fn enabled(&self) -> bool

Enabled returns whether or not the keybinding is enabled. Disabled keybindings won’t be activated and won’t show up in help. Keybindings are enabled by default.

pub fn set_enabled(&mut self, v: bool)

SetEnabled enables or disables the keybinding.

pub fn unbind(&mut self)

Unbind removes the keys and help from this binding, effectively nullifying it. This is a step beyond disabling it, since applications can enable or disable key bindings based on application state.