pub enum FilterState {
Unfiltered,
Filtering,
FilterApplied,
}Expand description
FilterState describes the current filtering state on the model.
Variants
Unfiltered
no filter set
Filtering
user is actively setting a filter
FilterApplied
a filter is applied and user is not editing filter
Implementations