pub struct DefaultItemStyles {
pub normal_title: Style,
pub normal_desc: Style,
pub selected_title: Style,
pub selected_desc: Style,
pub dimmed_title: Style,
pub dimmed_desc: Style,
pub filter_match: Style,
}Expand description
DefaultItemStyles defines styling for a default list item.
See DefaultItemView for when these come into play.
Fields
normal_title: StyleThe Normal state.
normal_desc: StyleThe Normal state.
selected_title: StyleThe selected item state.
selected_desc: StyleThe selected item state.
dimmed_title: StyleThe dimmed state, for when the filter input is initially activated.
dimmed_desc: StyleThe dimmed state, for when the filter input is initially activated.
filter_match: StyleCharacters matching the current filter, if any.