pub struct Rank {
pub index: usize,
pub matched_indexes: Vec<usize>,
}Expand description
Rank defines a rank for a given item.
Fields
index: usizeThe index of the item in the original input.
matched_indexes: Vec<usize>Indices of the actual word that were matched against the filter term.