with_width

Function with_width 

pub fn with_width(w: usize) -> Option
WithWidth sets the initial width of the progress bar. Note that you can also set the width via the width property, which can come in handy if you’re waiting for a tea.WindowSizeMsg.