Model

Struct Model 

pub struct Model {
    pub spinner: Spinner,
    pub style: Style,
    /* private fields */
}
Model contains the state for the spinner. Use new to create new models rather than using Model as a struct literal.

Fields

spinner: Spinner

Spinner settings to use. See type Spinner.

style: Style

Style sets the styling for the spinner. Most of the time you’ll just want foreground and background coloring, and potentially some padding.

Implementations

Source

impl Model

ID returns the spinner’s unique ID.

pub fn id(&self) -> i32

ID returns the spinner’s unique ID.

pub fn update(&mut self, msg: &dyn Msg) -> Cmd

Update is the Tea update function.

pub fn view(&self) -> String

View renders the model’s view.

pub fn tick_msg(&self) -> TickMsg

Tick is the command used to advance the spinner one frame. Use this command to effectively start the spinner.