pub struct TickMsg {
pub time: SystemTime,
pub id: i32,
/* private fields */
}Expand description
TickMsg indicates that the timer has ticked and we should render a frame.
Fields
time: SystemTimeThe time at which the tick occurred.
id: i32The ID of the spinner that this message belongs to.