Module stopwatch

Module stopwatch 

Cleanroom Rust port of upstream Go source file: stopwatch/stopwatch.go Upstream Target Tag / Version: v2.1.0

# Stopwatch

A simple stopwatch component.

Structs

Model
Model for the stopwatch component.
ResetMsg
ResetMsg is sent when the stopwatch should reset.
StartStopMsg
StartStopMsg is sent when the stopwatch should start or stop.
TickMsg
TickMsg is a message that is sent on every timer tick.

Functions

new
New creates a new stopwatch with 1s interval.
with_interval
WithInterval is an option for setting the interval between ticks. Pass as an argument to new.

Type Aliases

Option
Option is a configuration option in new. For example: