pub struct TickMsg {
pub id: i32,
/* private fields */
}Expand description
TickMsg is a message that is sent on every timer tick.
Fields
id: i32ID is the identifier of the stopwatch that sends the message. This makes it possible to determine which stopwatch a tick belongs to when there are multiple stopwatches running.
Note, however, that a stopwatch will reject ticks from other stopwatches, so it’s safe to flow all TickMsgs through all stopwatches and have them still behave appropriately.