Module table

Module table 

Cleanroom Rust port of upstream Go source file: table/table.go Upstream Target Tag / Version: v2.1.0

# Table

A simple table component for Bubble Tea applications.

Structs

Column
Column defines the table structure.
KeyMap
KeyMap defines keybindings. It satisfies to the help.KeyMap interface, which is used to render the help menu.
Model
Model defines a state for the table widget.
Styles
Styles contains style definitions for this list component. By default, these values are generated by default_styles.

Functions

default_key_map
DefaultKeyMap returns a default set of keybindings.
default_styles
DefaultStyles returns a set of default style definitions for this table.
new
New creates a new model for the table widget.
with_columns
WithColumns sets the table columns (headers).
with_focused
WithFocused sets the focus state of the table.
with_height
WithHeight sets the height of the table.
with_key_map
WithKeyMap sets the key map.
with_rows
WithRows sets the table rows (data).
with_styles
WithStyles sets the table styles.
with_width
WithWidth sets the width of the table.

Type Aliases

Option
Option is used to set options in new. For example:
Row
Row represents one line in the table.