KeyMap

Struct KeyMap 

pub struct KeyMap {
    pub line_up: Binding,
    pub line_down: Binding,
    pub page_up: Binding,
    pub page_down: Binding,
    pub half_page_up: Binding,
    pub half_page_down: Binding,
    pub goto_top: Binding,
    pub goto_bottom: Binding,
}
KeyMap defines keybindings. It satisfies to the help.KeyMap interface, which is used to render the help menu.

Fields

line_up: Binding

LineUp binding.

line_down: Binding

LineDown binding.

page_up: Binding

PageUp binding.

page_down: Binding

PageDown binding.

half_page_up: Binding

HalfPageUp binding.

half_page_down: Binding

HalfPageDown binding.

goto_top: Binding

GotoTop binding.

goto_bottom: Binding

GotoBottom binding.

Implementations

Source

impl KeyMap

ShortHelp implements the KeyMap interface.

pub fn short_help(&self) -> Vec<Binding>

ShortHelp returns the bindings shown in the abbreviated help view.

pub fn full_help(&self) -> Vec<Vec<Binding>>

FullHelp returns the bindings shown in the full help view.