Model

Struct Model 

pub struct Model {
    pub key_map: KeyMap,
    pub help: Model,
    /* private fields */
}
Model defines a state for the table widget.

Fields

key_map: KeyMap

The key bindings for the table.

help: Model

The help view for the table.

Implementations

Source

impl Model

pub fn set_styles(&mut self, s: Styles)

SetStyles sets the table styles.

pub fn update(&mut self, msg: &dyn Msg) -> Cmd

Update is the Bubble Tea update loop.

pub fn focused(&self) -> bool

Focused returns the focus state of the table.

pub fn focus(&mut self)

Focus focuses the table, allowing the user to move around the rows and interact.

pub fn blur(&mut self)

Blur blurs the table, preventing selection or movement.

pub fn view(&self) -> String

View renders the component.

pub fn help_view(&self) -> String

HelpView is a helper method for rendering the help menu from the keymap. Note that this view is not rendered by default and you must call it manually in your application, where applicable.

pub fn update_viewport(&mut self)

UpdateViewport updates the list content based on the previously defined columns and rows.

pub fn selected_row(&self) -> Option<Row>

SelectedRow returns the selected row.

pub fn rows(&self) -> &[Row]

Rows returns the current rows.

pub fn columns(&self) -> &[Column]

Columns returns the current columns.

pub fn set_rows(&mut self, r: &[Row])

SetRows sets a new rows state.

pub fn set_columns(&mut self, c: &[Column])

SetColumns sets a new columns state.

pub fn set_width(&mut self, w: usize)

SetWidth sets the width of the viewport of the table.

pub fn set_height(&mut self, h: usize)

SetHeight sets the height of the viewport of the table.

pub fn height(&self) -> usize

Height returns the viewport height of the table.

pub fn width(&self) -> usize

Width returns the viewport width of the table.

pub fn cursor(&self) -> usize

Cursor returns the index of the selected row.

pub fn set_cursor(&mut self, n: usize)

SetCursor sets the cursor position in the table.

pub fn move_up(&mut self, n: usize)

MoveUp moves the selection up by any number of rows. It can not go above the first row.

pub fn move_down(&mut self, n: usize)

MoveDown moves the selection down by any number of rows. It can not go below the last row.

pub fn goto_top(&mut self)

GotoTop moves the selection to the first row.

pub fn goto_bottom(&mut self)

GotoBottom moves the selection to the last row.

pub fn from_values(&mut self, value: &str, separator: &str)

FromValues create the table rows from a simple string. It uses \n by default for getting all the rows and the given separator for the fields on each row.