CursorStyle

Struct CursorStyle 

pub struct CursorStyle {
    pub color: Color,
    pub shape: CursorShape,
    pub blink: bool,
    pub blink_speed: Duration,
}
CursorStyle is the style for real and virtual cursors.

Fields

color: Color

Style styles the cursor block. For real cursors, the foreground color set here will be used as the cursor color.

shape: CursorShape

Shape is the cursor shape. The following shapes are available:

blink: bool

CursorBlink determines whether or not the cursor should blink.

blink_speed: Duration

BlinkSpeed is the speed at which the virtual cursor blinks. This has no effect on real cursors as well as no effect if the cursor is set not to blink.