LineInfo

Struct LineInfo 

pub struct LineInfo {
    pub width: usize,
    pub char_width: usize,
    pub height: usize,
    pub start_column: usize,
    pub column_offset: usize,
    pub row_offset: usize,
    pub char_offset: usize,
}
LineInfo is a helper for keeping track of line information regarding soft-wrapped lines.

Fields

width: usize

Width is the number of columns in the line.

char_width: usize

CharWidth is the number of characters in the line to account for double-width runes.

height: usize

Height is the number of rows in the line.

start_column: usize

StartColumn is the index of the first column of the line.

column_offset: usize

ColumnOffset is the number of columns that the cursor is offset from the start of the line.

row_offset: usize

RowOffset is the number of rows that the cursor is offset from the start of the line.

char_offset: usize

CharOffset is the number of characters that the cursor is offset from the start of the line. This will generally be equivalent to ColumnOffset, but will be different if there are double-width runes before the cursor.