StyleState

Struct StyleState 

pub struct StyleState {
    pub base: Style,
    pub text: Style,
    pub line_number: Style,
    pub cursor_line_number: Style,
    pub cursor_line: Style,
    pub end_of_buffer: Style,
    pub placeholder: Style,
    pub prompt: Style,
}
StyleState that will be applied to the text area.

StyleState can be applied to focused and unfocused states to change the styles depending on the focus state.

Fields

base: Style

The base style.

text: Style

The text style.

line_number: Style

The line number style.

cursor_line_number: Style

The cursor line number style.

cursor_line: Style

The cursor line style.

end_of_buffer: Style

The end-of-buffer style.

placeholder: Style

The placeholder style.

prompt: Style

The prompt style.