pub struct Styles {
pub focused: StyleState,
pub blurred: StyleState,
pub cursor: CursorStyle,
}Expand description
Styles are the styles for the textarea, separated into focused and blurred states. The appropriate styles will be chosen based on the focus state of the textarea.
Fields
focused: StyleStateThe styles used when focused.
blurred: StyleStateThe styles used when blurred.
cursor: CursorStyleThe cursor style.