pub enum EchoMode {
EchoNormal,
EchoPassword,
EchoNone,
}Expand description
EchoMode sets the input behavior of the text input field.
Variants
EchoNormal
EchoNormal displays text as is. This is the default behavior.
EchoPassword
EchoPassword displays the EchoCharacter mask instead of actual characters. This is commonly used for password fields.
EchoNone
EchoNone displays nothing as characters are entered. This is commonly seen for password fields on the command line.