pub struct StyleState {
pub text: Style,
pub placeholder: Style,
pub suggestion: Style,
pub prompt: Style,
}Expand description
StyleState that will be applied to the text area.
StyleState can be applied to focused and unfocused states to change the styles depending on the focus state.
Fields
text: StyleStyle for the text.
placeholder: StyleStyle for the placeholder.
suggestion: StyleStyle for the suggestion.
prompt: StyleStyle for the prompt.