Styles

Struct Styles 

pub struct Styles {
    pub focused: StyleState,
    pub blurred: StyleState,
    pub cursor: CursorStyle,
}
Styles are the styles for the textarea, separated into focused and blurred states. The appropriate styles will be chosen based on the focus state of the textarea.

Fields

focused: StyleState

The styles used when focused.

blurred: StyleState

The styles used when blurred.

cursor: CursorStyle

The cursor style.