pub struct TickMsg {
pub id: i32,
pub timeout: bool,
/* private fields */
}Expand description
TickMsg is a message that is sent on every timer tick.
Fields
id: i32ID is the identifier of the timer that sends the message. This makes it possible to determine which timer a tick belongs to when there are multiple timers running.
Note, however, that a timer will reject ticks from other timers, so it’s safe to flow all TickMsgs through all timers and have them still behave appropriately.
timeout: boolTimeout returns whether or not this tick is a timeout tick. You can alternatively listen for TimeoutMsg.