pub struct GutterContext {
pub index: usize,
pub total_lines: usize,
pub soft: bool,
}Expand description
GutterContext provides context to a GutterFunc.
Fields
index: usizeIndex is the line index of the line which the gutter is being rendered for.
total_lines: usizeTotalLines is the total number of lines in the viewport.
soft: boolSoft is whether or not the line is soft wrapped.