pub struct HighlightInfo {
pub line_start: usize,
pub line_end: usize,
pub lines: HashMap<usize, (usize, usize)>,
}Expand description
HighlightInfo holds the highlight ranges for a set of matches.
This is exposed so integration tests can assert on highlight ranges the same way the upstream in-package tests do.
Fields
line_start: usizein which line this highlight starts and ends
line_end: usizein which line this highlight ends
lines: HashMap<usize, (usize, usize)>the grapheme highlight ranges for each of these lines