Cleanroom Rust port of upstream Go source file: cursor/cursor.go
Upstream Target Tag / Version: v2.1.0
A virtual cursor to support the textinput and textarea elements.
Structs
- Blink
Msg - BlinkMsg signals that the cursor should blink. It contains metadata that allows us to tell if the blink message is the one we’re expecting.
- Model
- Model is the Bubble Tea model for this cursor element.
Enums
- Mode
- Mode describes the behavior of the cursor.