Model

Struct Model 

pub struct Model {
Show 13 fields pub path: String, pub current_directory: String, pub allowed_types: Vec<String>, pub key_map: KeyMap, pub show_permissions: bool, pub show_size: bool, pub show_hidden: bool, pub dir_allowed: bool, pub file_allowed: bool, pub file_selected: String, pub auto_height: bool, pub cursor: String, pub styles: Styles, /* private fields */
}
Model represents a file picker.

Fields

path: String

Path is the path which the user has selected with the file picker.

current_directory: String

CurrentDirectory is the directory that the user is currently in.

allowed_types: Vec<String>

AllowedTypes specifies which file types the user may select. If empty the user may select any file.

key_map: KeyMap

The key bindings for the file picker.

show_permissions: bool

Whether to show permissions.

show_size: bool

Whether to show file sizes.

show_hidden: bool

Whether to show hidden files.

dir_allowed: bool

Whether directories can be selected.

file_allowed: bool

Whether files can be selected.

file_selected: String

The currently selected file.

auto_height: bool

Whether the height is automatically managed.

cursor: String

The cursor string.

styles: Styles

The styles of the file picker.

Implementations

Source

impl Model

pub fn set_height(&mut self, h: usize)

SetHeight sets the height of the file picker.

pub fn height(&self) -> usize

Height returns the height of the file picker.

pub fn init(&self) -> Cmd

Init initializes the file picker model.

pub fn update(&mut self, msg: &dyn Msg) -> Cmd

Update handles user interactions within the file picker model.

pub fn view(&self) -> String

View returns the view of the file picker.

pub fn did_select_file(&self, msg: &dyn Msg) -> (bool, String)

DidSelectFile returns whether a user has selected a file (on this msg).

pub fn did_select_disabled_file(&self, msg: &dyn Msg) -> (bool, String)

DidSelectDisabledFile returns whether a user tried to select a disabled file (on this msg).

pub fn highlighted_path(&self) -> String

HighlightedPath returns the path of the currently highlighted file or directory.