pub struct MemoCache<T> { /* private fields */ }Expand description
MemoCache is a struct that represents a cache with a set capacity. It uses an LRU (Least Recently Used) eviction policy.
Implementations
Sourceimpl<T> MemoCache<T>
impl<T> MemoCache<T>
Sourcepub fn size(&self) -> usize
pub fn size(&self) -> usize
Size returns the current size of the MemoCache. It is the number of items currently stored in the cache.