pub trait Hasher {
// Required method
fn hash(&self) -> String;
}Expand description
Hasher is an interface that requires a Hash method. The Hash method is expected to return a string representation of the hash of the object.
Required Methods
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".