Cleanroom Rust port of upstream Go source file: internal/runeutil/runeutil.go
Upstream Target Tag / Version: v2.1.0
Structs
Traits
- Sanitizer
- Sanitizer is a helper for bubble widgets that want to process Runes from input key messages.
Functions
- new_
sanitizer - NewSanitizer constructs a rune sanitizer.
- replace_
newlines - ReplaceNewlines replaces newline characters by the specified string.
- replace_
tabs - ReplaceTabs replaces tabs by the specified string.
Type Aliases
- Option
- Option is the type of option that can be passed to Sanitize().