pub struct Binding { /* private fields */ }Expand description
Binding describes a set of keybindings and, optionally, their associated help text.
Implementations
Sourceimpl Binding
impl Binding
Sourcepub fn set_help(&mut self, key: &str, desc: &str)
pub fn set_help(&mut self, key: &str, desc: &str)
SetHelp sets the help text for the keybinding.
Sourcepub fn enabled(&self) -> bool
pub fn enabled(&self) -> bool
Enabled returns whether or not the keybinding is enabled. Disabled keybindings won’t be activated and won’t show up in help. Keybindings are enabled by default.
Sourcepub fn set_enabled(&mut self, v: bool)
pub fn set_enabled(&mut self, v: bool)
SetEnabled enables or disables the keybinding.