pub struct DefaultDelegate {
pub show_description: bool,
pub styles: DefaultItemStyles,
pub update_func: Option<Box<dyn Fn(&dyn Msg, &Model) -> Cmd + Send + Sync>>,
pub short_help_func: Option<Box<dyn Fn() -> Vec<Binding> + Send + Sync>>,
pub full_help_func: Option<Box<dyn Fn() -> Vec<Vec<Binding>> + Send + Sync>>,
/* private fields */
}Expand description
DefaultDelegate is a standard delegate designed to work in lists. It’s
styled by DefaultItemStyles, which can be customized as you like.
The description line can be hidden by setting show_description to
false, which renders the list as single-line-items. The spacing between
items can be set with the set_spacing method.
Fields
show_description: boolWhether to show the description line.
styles: DefaultItemStylesThe styles for the delegate.
update_func: Option<Box<dyn Fn(&dyn Msg, &Model) -> Cmd + Send + Sync>>An optional update function called on item updates.
short_help_func: Option<Box<dyn Fn() -> Vec<Binding> + Send + Sync>>An optional short help function.
full_help_func: Option<Box<dyn Fn() -> Vec<Vec<Binding>> + Send + Sync>>An optional full help function.
Implementations
Sourceimpl DefaultDelegate
impl DefaultDelegate
Sourcepub fn set_height(&mut self, i: usize)
pub fn set_height(&mut self, i: usize)
SetHeight sets delegate’s preferred height.
Sourcepub fn height(&self) -> usize
pub fn height(&self) -> usize
Height returns the delegate’s preferred height. This has effect only if ShowDescription is true, otherwise height is always 1.
Sourcepub fn set_spacing(&mut self, i: usize)
pub fn set_spacing(&mut self, i: usize)
SetSpacing sets the delegate’s spacing.