Module paginator

Module paginator 

Cleanroom Rust port of upstream Go source file: paginator/paginator.go Upstream Target Tag / Version: v2.1.0

# Paginator

A Bubble Tea package for calculating pagination and rendering pagination info. Note that this package does not render actual pages: it’s purely for handling keystrokes related to pagination, and rendering pagination status.

Structs

KeyMap
KeyMap is the key bindings for different actions within the paginator.
Model
Model is the Bubble Tea model for this user interface.

Enums

Type
Type specifies the way we render pagination.

Functions

default_key_map
DefaultKeyMap is the default set of key bindings for navigating and acting upon the paginator.
new
New creates a new model with defaults.
with_per_page
WithPerPage sets the total pages.
with_total_pages
WithTotalPages sets the total pages.

Type Aliases

Option
Option is used to set options in new.