pub fn with_scaled(enabled: bool) -> OptionExpand description
WithScaled sets whether to scale the blend/gradient to fit the width of only the filled portion of the progress bar. The default is false, which means the percentage must be 100% to see the full color blend/gradient.
This is ignored when not using blending/multiple colors.