Cleanroom Rust port of upstream Go source file: spinner/spinner.go
Upstream Target Tag / Version: v2.1.0
A spinner component for Bubble Tea applications.
Structs
- Model
- Model contains the state for the spinner. Use
newto create new models rather than using Model as a struct literal. - Spinner
- Spinner is a set of frames used in animating the spinner.
- TickMsg
- TickMsg indicates that the timer has ticked and we should render a frame.
Functions
- dot
- A spinner of braille dots.
- ellipsis
- An ellipsis spinner.
- globe
- A globe spinner.
- hamburger
- A hamburger spinner.
- jump
- A jumping spinner.
- line
- Some spinners to choose from. You could also make your own.
- meter
- A meter spinner.
- mini_
dot - A mini braille-dot spinner.
- monkey
- A monkey spinner.
- moon
- A moon spinner.
- new
- New returns a model with default values.
- points
- A points spinner.
- pulse
- A pulsing block spinner.
- with_
spinner - WithSpinner is an option to set the spinner. Pass this to
new. - with_
style - WithStyle is an option to set the spinner style. Pass this to
new.