pub struct CursorStyle {
pub color: Color,
pub shape: CursorShape,
pub blink: bool,
pub blink_speed: Duration,
}Expand description
CursorStyle is the style for real and virtual cursors.
Fields
color: ColorStyle styles the cursor block. For real cursors, the foreground color set here will be used as the cursor color.
shape: CursorShapeShape is the cursor shape. The following shapes are available:
blink: boolCursorBlink determines whether or not the cursor should blink.
blink_speed: DurationBlinkSpeed is the speed at which the virtual cursor blinks. This has no effect on real cursors as well as no effect if the cursor is set not to blink.