pub struct StyleState {
pub base: Style,
pub text: Style,
pub line_number: Style,
pub cursor_line_number: Style,
pub cursor_line: Style,
pub end_of_buffer: Style,
pub placeholder: Style,
pub prompt: Style,
}Expand description
StyleState that will be applied to the text area.
StyleState can be applied to focused and unfocused states to change the styles depending on the focus state.
Fields
base: StyleThe base style.
text: StyleThe text style.
line_number: StyleThe line number style.
cursor_line_number: StyleThe cursor line number style.
cursor_line: StyleThe cursor line style.
end_of_buffer: StyleThe end-of-buffer style.
placeholder: StyleThe placeholder style.
prompt: StyleThe prompt style.